==> dagr-vebchar-0.5.1-sources.jar: net/aequologica/neo/dagr/servlet/mobile/Listener.java <==
package net.aequologica.neo.dagr.servlet.mobile;

import static net.aequologica.neo.geppaequo.config.ConfigRegistry.CONFIG_REGISTRY;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;

import javax.inject.Inject;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.io.CharStreams;

import net.aequologica.neo.dagr.DagsSingleton;
import net.aequologica.neo.dagr.DagsSingleton.Dags;
import net.aequologica.neo.dagr.bus.Bus;
import net.aequologica.neo.dagr.bus.BusEvent;
import net.aequologica.neo.dagr.config.DagrConfig;
import net.aequologica.neo.dagr.model.Dag.Node;
import net.aequologica.neo.geppaequo.crypto.Codec;
import rx.Subscription;

// @WebListener
public class Listener implements ServletContextListener {
    
    private final static Logger log = LoggerFactory.getLogger(Listener.class);

    private ObjectMapper  mapper;
    private String        googleCloudMessagingAPIKey;

    private Subscription subscription;
    
    private Dags dags = DagsSingleton.INSTANCE.dags;
    
    public Listener() throws Exception {
    }
    
    @Inject Codec codec;

    @Override
    public void contextInitialized(ServletContextEvent arg0)  { 

        this.mapper = new ObjectMapper();
        try {
            this.googleCloudMessagingAPIKey = codec.decrypt(CONFIG_REGISTRY.getConfig(DagrConfig.class).getEncryptedGoogleCloudMessagingAPIKey().toCharArray());
        } catch (Exception e) {
            e.printStackTrace();
        }

        Bus<Node> theBus = dags.getBusFromTravis("aequologica", null);
        
        if (theBus != null) {
            subscription = theBus.toObservable()
                    .filter(    event -> event.getType().equals(BusEvent.Type.CLEAN_OK) || event.getType().equals(BusEvent.Type.CLEAN_ERROR) || event.getType().equals(BusEvent.Type.CLEAN_ABORTED))
                    .map(       event -> event.get())
                    .subscribe( node  -> sendNotification(node));
        } 
        
        log.debug("[gcm] subbscribed !");
        
    }
    @Override
    public void contextDestroyed(ServletContextEvent arg0)  { 
        if (subscription != null) {
            subscription.unsubscribe();
            log.debug("[gcm] unsubscribed !");
        }
    }
	
    void sendNotification(Node node) {
        
        // balance le groove sur les portables
        StringBuilder sb = new StringBuilder();
        sb.append(" ");
        sb.append(node.getName());
        sb.append(" @ ");
        sb.append("travis");
        
        String message = sb.toString();
        log.debug("[gcm] sending notification {} for node {} to google cloud messaging", message, node.getName());
        
        try {
            GCMMessage msg = new GCMMessage(new GCMMessage.Data(message));
            
            String gcmMessageAsString = mapper.writeValueAsString(msg);
            
            // Create connection to send GCM Message request.
            URL url = new URL("https://android.googleapis.com/gcm/send");
            HttpURLConnection conn = (HttpURLConnection) url.openConnection();
            conn.setRequestProperty("Authorization", "key=" + googleCloudMessagingAPIKey);
            conn.setRequestProperty("Content-Type", "application/json; charset=utf-8");
            conn.setRequestMethod("POST");
            conn.setDoOutput(true);

            // Send GCM message content.
            OutputStream outputStream = conn.getOutputStream();
            outputStream.write(gcmMessageAsString.getBytes(StandardCharsets.UTF_8));

            // Read GCM response.
            InputStream inputStream = conn.getInputStream();
            String responseText = CharStreams.toString(new InputStreamReader(inputStream));
            
            log.debug("[gcm] Check your device/emulator for notification or logcat for confirmation of the receipt of the GCM message. GCM Response text is {}", responseText);
        
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
    
    /* e.g.
     * { "data" : {
     *     "message" : "blah"
     *   },
     *   "to" : "/topics/global"
     * } 
     */
    // GCM = Google Cloud Messaging
    private static class GCMMessage {
        
        @JsonProperty
        private final String to = "/topics/global";
        
        @JsonProperty
        private Data data;
        
        public GCMMessage() {
        }

        public GCMMessage(final Data data) {
            this.data = data;
        }
        
        private static class Data {
            @JsonProperty
            private String message;

            public Data() {
            }

            public Data(final String message) {
                this.message = message;
            }

        }
    }
    
}

==> dagr-vebchar-0.5.2-sources.jar: net/aequologica/neo/dagr/servlet/mobile/Listener.java <==
package net.aequologica.neo.dagr.servlet.mobile;

import static net.aequologica.neo.geppaequo.config.ConfigRegistry.CONFIG_REGISTRY;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;

import javax.inject.Inject;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.io.CharStreams;
import net.aequologica.neo.dagr.Scope;
import net.aequologica.neo.dagr.bus.Bus;
import net.aequologica.neo.dagr.bus.BusEvent;
import net.aequologica.neo.dagr.config.DagrConfig;
import net.aequologica.neo.dagr.model.Dag.Node;
import net.aequologica.neo.geppaequo.crypto.Codec;

import io.reactivex.disposables.Disposable;

// @WebListener
public class Listener implements ServletContextListener {
    
    private final static Logger log = LoggerFactory.getLogger(Listener.class);

    private ObjectMapper  mapper;
    private String        googleCloudMessagingAPIKey;

    private Disposable subscription;
    
    public Listener() throws Exception {
    }
    
    @Inject Codec codec;

    @Override
    public void contextInitialized(ServletContextEvent arg0)  { 

        this.mapper = new ObjectMapper();
        try {
            this.googleCloudMessagingAPIKey = codec.decrypt(CONFIG_REGISTRY.getConfig(DagrConfig.class).getEncryptedGoogleCloudMessagingAPIKey().toCharArray());
        } catch (Exception e) {
            e.printStackTrace();
        }

        String dagName = null;
        String scope = null;
        Bus<Node, Scope> theBus = getBusFromGoogleCloudMessaging(dagName, scope);
        
        if (theBus != null) {
            subscription = theBus.toObservable()
                    .filter(    event -> event.getType().equals(BusEvent.Type.CLEAN_OK) || 
                                                                event.getType().equals(BusEvent.Type.CLEAN_ERROR) || 
                                                                event.getType().equals(BusEvent.Type.CLEAN_ABORTED))
                    .map(       event -> event.get())
                    .subscribe( node  -> sendNotification(node));
        } 
        
        log.debug("[gcm] subbscribed !");
        
    }

    private Bus<Node, Scope> getBusFromGoogleCloudMessaging(String dagName, String scope) {
        throw new UnsupportedOperationException();
    }
    
    @Override
    public void contextDestroyed(ServletContextEvent arg0)  { 
        if (subscription != null) {
            subscription.dispose();
            log.debug("[gcm] unsubscribed !");
        }
    }
	
    void sendNotification(Node node) {
        
        // balance le groove sur les portables
        StringBuilder sb = new StringBuilder();
        sb.append(" ");
        sb.append(node.getName());
        sb.append(" @ ");
        sb.append("travis");
        
        String message = sb.toString();
        log.debug("[gcm] sending notification {} for node {} to google cloud messaging", message, node.getName());
        
        try {
            GCMMessage msg = new GCMMessage(new GCMMessage.Data(message));
            
            String gcmMessageAsString = mapper.writeValueAsString(msg);
            
            // Create connection to send GCM Message request.
            URL url = new URL("https://android.googleapis.com/gcm/send");
            HttpURLConnection conn = (HttpURLConnection) url.openConnection();
            conn.setRequestProperty("Authorization", "key=" + googleCloudMessagingAPIKey);
            conn.setRequestProperty("Content-Type", "application/json; charset=utf-8");
            conn.setRequestMethod("POST");
            conn.setDoOutput(true);

            // Send GCM message content.
            OutputStream outputStream = conn.getOutputStream();
            outputStream.write(gcmMessageAsString.getBytes(StandardCharsets.UTF_8));

            // Read GCM response.
            InputStream inputStream = conn.getInputStream();
            String responseText = CharStreams.toString(new InputStreamReader(inputStream));
            
            log.debug("[gcm] Check your device/emulator for notification or logcat for confirmation of the receipt of the GCM message. GCM Response text is {}", responseText);
        
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
    
    /* e.g.
     * { "data" : {
     *     "message" : "blah"
     *   },
     *   "to" : "/topics/global"
     * } 
     */
    // GCM = Google Cloud Messaging
    @SuppressWarnings("unused")
    private static class GCMMessage {
        
        @JsonProperty
        private final String to = "/topics/global";
        
        @JsonProperty
        private Data data;
        
        public GCMMessage() {
        }

        public GCMMessage(final Data data) {
            this.data = data;
        }
        
        private static class Data {
            @JsonProperty
            private String message;

            public Data() {
            }

            public Data(final String message) {
                this.message = message;
            }

        }
    }
    
}
